@@ -1,26 +1,40 @@
-__version__ = "1.0.59"
+__version__ = "1.0.60"
 
 import kappadata.caching
 import kappadata.copying
 import kappadata.datasets
 import kappadata.loading
 import kappadata.transforms
+import kappadata.transforms.norm
 import kappadata.wrappers
 import kappadata.wrappers.dataset_wrappers
 import kappadata.wrappers.sample_wrappers
+# batch_samplers
 from .batch_samplers.infinite_batch_sampler import InfiniteBatchSampler
+# caching
 from .caching.shared_dict_dataset import SharedDictDataset
+# collators
 from .collators.base.kd_compose_collator import KDComposeCollator
 from .collators.base.kd_single_collator import KDSingleCollator
 from .collators.kd_mix_collator import KDMixCollator
 from .collators.pad_sequences_collator import PadSequencesCollator
-from .copying import copy_imagefolder_from_global_to_local
+# copying
+from .copying import (
+    copy_imagefolder_from_global_to_local,
+    create_zipped_imagefolder_classwise,
+    unzip_imagefolder_classwise,
+)
+# datasets
 from .datasets.kd_concat_dataset import KDConcatDataset
 from .datasets.kd_dataset import KDDataset
 from .datasets.kd_subset import KDSubset
 from .datasets.kd_wrapper import KDWrapper
+# transforms base
 from .transforms.base.kd_compose_transform import KDComposeTransform
 from .transforms.base.kd_transform import KDTransform
+# transforms
+from .transforms.image_pos_embed_grid import ImagePosEmbedGrid
+from .transforms.image_pos_embed_sincos import ImagePosEmbedSincos
 from .transforms.kd_color_jitter import KDColorJitter
 from .transforms.kd_gaussian_blur_pil import KDGaussianBlurPIL
 from .transforms.kd_gaussian_blur_tv import KDGaussianBlurTV
@@ -33,12 +47,24 @@ from .transforms.kd_random_grayscale import KDRandomGrayscale
 from .transforms.kd_random_horizontal_flip import KDRandomHorizontalFlip
 from .transforms.kd_random_resized_crop import KDRandomResizedCrop
 from .transforms.kd_random_solarize import KDRandomSolarize
+# transforms norm
+from .transforms.norm.kd_cifar10_norm import KDCifar10Norm
+from .transforms.norm.kd_image_net_norm import KDImageNetNorm
+from .transforms.norm.kd_image_norm import KDImageNorm
+from .transforms.norm.kd_image_range_norm import KDImageRangeNorm
+from .transforms.patchify_image import PatchifyImage
+from .transforms.patchwise_random_rotation import PatchwiseRandomRotation
+from .transforms.patchwise_shuffle import PatchwiseShuffle
+from .transforms.save_state_to_context_transform import SaveStateToContextTransform
+from .transforms.unpatchify_image import UnpatchifyImage
+# wrappers.dataset_wrappers
 from .wrappers.dataset_wrappers.class_filter_wrapper import ClassFilterWrapper
 from .wrappers.dataset_wrappers.oversampling_wrapper import OversamplingWrapper
 from .wrappers.dataset_wrappers.percent_filter_wrapper import PercentFilterWrapper
 from .wrappers.dataset_wrappers.repeat_wrapper import RepeatWrapper
 from .wrappers.dataset_wrappers.shuffle_wrapper import ShuffleWrapper
 from .wrappers.dataset_wrappers.subset_wrapper import SubsetWrapper
+from .wrappers.mode_wrapper import ModeWrapper
+# wrappers.sample_wrappers
 from .wrappers.sample_wrappers.label_smoothing_wrapper import LabelSmoothingWrapper
 from .wrappers.sample_wrappers.one_hot_wrapper import OneHotWrapper
-from .wrappers.mode_wrapper import ModeWrapper
